@@ -169,6 +169,9 @@ class RouteProvider implements CacheableRouteProviderInterface, PreloadableRoute
     if ($cached = $this->cache->get($cid)) {
       $this->currentPath->setPath($cached->data['path'], $request);
       $request->query->replace($cached->data['query']);
+      if ($cached->data['routes'] === FALSE) {
+        return new RouteCollection();
+      }
       return $cached->data['routes'];
     }
     else {
@@ -183,7 +186,7 @@ class RouteProvider implements CacheableRouteProviderInterface, PreloadableRoute
       $cache_value = [
         'path' => $path,
         'query' => $query_parameters,
-        'routes' => $routes,
+        'routes' => $routes->count() === 0 ? FALSE : $routes,
       ];
       $this->cache->set($cid, $cache_value, CacheBackendInterface::CACHE_PERMANENT, ['route_match']);
       return $routes;
@@ -233,7 +236,7 @@ class RouteProvider implements CacheableRouteProviderInterface, PreloadableRoute
 
           $this->cache->set($cid, $routes, Cache::PERMANENT, ['routes']);
         }
-        catch (\Exception $e) {
+        catch (\Exception) {
           $routes = [];
         }
       }
@@ -370,7 +373,7 @@ class RouteProvider implements CacheableRouteProviderInterface, PreloadableRoute
       ])
         ->fetchAll(\PDO::FETCH_ASSOC);
     }
-    catch (\Exception $e) {
+    catch (\Exception) {
       $routes = [];
     }
 
