@@ -5,8 +5,8 @@ declare(strict_types=1);
 namespace Drupal\Tests\editor\Unit\EditorXssFilter;
 
 use Drupal\editor\EditorXssFilter\Standard;
-use Drupal\Tests\UnitTestCase;
 use Drupal\filter\Plugin\FilterInterface;
+use Drupal\Tests\UnitTestCase;
 
 // cspell:ignore ascript attributename bgsound bscript ckers cript datafld
 // cspell:ignore dataformatas datasrc dynsrc ession livescript msgbox nmouseover
@@ -513,7 +513,7 @@ xss:ex/*XSS*//*/*/pression(alert("XSS"))\'>',
     // @see https://www.owasp.org/index.php/XSS_Filter_Evasion_Cheat_Sheet#URL_string_evasion
     // This one is irrelevant for Drupal; Drupal doesn't forbid linking to some
     // sites, it only forbids linking to any protocols other than those that are
-    // whitelisted.
+    // allowed.
 
     // Test XSS filtering on data-attributes.
     // @see \Drupal\editor\EditorXssFilter::filterXssDataAttributes()
@@ -547,7 +547,7 @@ xss:ex/*XSS*//*/*/pression(alert("XSS"))\'>',
   /**
    * Tests removing disallowed tags and XSS prevention.
    *
-   * \Drupal\Component\Utility\Xss::filter() has the ability to run in blacklist
+   * \Drupal\Component\Utility\Xss::filter() has the ability to run in remove
    * mode, in which it still applies the exact same filtering, with one
    * exception: it no longer works with a list of allowed tags, but with a list
    * of disallowed tags.
@@ -561,17 +561,17 @@ xss:ex/*XSS*//*/*/pression(alert("XSS"))\'>',
    * @param array $disallowed_tags
    *   (optional) The disallowed HTML tags to be passed to \Drupal\Component\Utility\Xss::filter().
    *
-   * @dataProvider providerTestBlackListMode
+   * @dataProvider providerTestDisallowMode
    */
-  public function testBlacklistMode($value, $expected, $message, array $disallowed_tags): void {
+  public function testDisallowMode($value, $expected, $message, array $disallowed_tags): void {
     $value = Standard::filter($value, $disallowed_tags);
     $this->assertSame($expected, $value, $message);
   }
 
   /**
-   * Data provider for testBlacklistMode().
+   * Data provider for testDisallowMode().
    *
-   * @see testBlacklistMode()
+   * @see testDisallowMode()
    *
    * @return array
    *   An array of arrays containing the following elements:
@@ -580,7 +580,7 @@ xss:ex/*XSS*//*/*/pression(alert("XSS"))\'>',
    *     - The assertion message.
    *     - (optional) The disallowed HTML tags to be passed to \Drupal\Component\Utility\Xss::filter().
    */
-  public static function providerTestBlackListMode() {
+  public static function providerTestDisallowMode() {
     return [
       [
         '<unknown style="visibility:hidden">Pink Fairy Armadillo</unknown><video src="gerenuk.mp4"><script>alert(0)</script>',
