@@ -20,7 +20,6 @@ use Drupal\user\UserInterface;
  * Tests the file field widget with public and private files.
  *
  * @group file
- * @group #slow
  */
 class FileFieldWidgetTest extends FileFieldTestBase {
 
@@ -560,7 +559,7 @@ class FileFieldWidgetTest extends FileFieldTestBase {
    * @param \Drupal\user\UserInterface $attacker_user
    *   The attacker user.
    */
-  protected function doTestTemporaryFileRemovalExploit(UserInterface $victim_user, UserInterface $attacker_user) {
+  protected function doTestTemporaryFileRemovalExploit(UserInterface $victim_user, UserInterface $attacker_user): void {
     $type_name = 'article';
     $field_name = 'test_file_field';
     $this->createFileField($field_name, 'node', $type_name);
