@@ -27,7 +27,6 @@ use GuzzleHttp\RequestOptions;
  * JSON:API regression tests.
  *
  * @group jsonapi
- * @group #slow
  *
  * @internal
  */
@@ -56,7 +55,7 @@ class JsonApiRegressionTest extends JsonApiFunctionalTestBase {
     // Set up data model.
     $this->assertTrue($this->container->get('module_installer')->install(['comment'], TRUE), 'Installed modules.');
     $this->addDefaultCommentField('node', 'article');
-    $this->addDefaultCommentField('taxonomy_term', 'tags', 'comment', CommentItemInterface::OPEN, 'tcomment');
+    $this->addDefaultCommentField('taxonomy_term', 'tags', 'comment', CommentItemInterface::OPEN, 'test_comment_type');
     $this->drupalCreateContentType(['type' => 'page']);
     $this->createEntityReferenceField(
       'node',
@@ -68,7 +67,7 @@ class JsonApiRegressionTest extends JsonApiFunctionalTestBase {
       [
         'target_bundles' => [
           'comment' => 'comment',
-          'tcomment' => 'tcomment',
+          'test_comment_type' => 'test_comment_type',
         ],
       ],
       FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED
