@@ -13,7 +13,6 @@ use Drupal\search\Entity\SearchPage;
  * JSON:API integration test for the "SearchPage" config entity type.
  *
  * @group jsonapi
- * @group #slow
  */
 class SearchPageTest extends ConfigEntityResourceTestBase {
 
@@ -47,7 +46,7 @@ class SearchPageTest extends ConfigEntityResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUpAuthorization($method) {
+  protected function setUpAuthorization($method): void {
     switch ($method) {
       case 'GET':
         $this->grantPermissionsToTestedRole(['access content']);
@@ -78,7 +77,7 @@ class SearchPageTest extends ConfigEntityResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function getExpectedDocument() {
+  protected function getExpectedDocument(): array {
     $self_url = Url::fromUri('base:/jsonapi/search_page/search_page/' . $this->entity->uuid())->setAbsolute()->toString(TRUE)->getGeneratedUrl();
     return [
       'jsonapi' => [
@@ -122,7 +121,7 @@ class SearchPageTest extends ConfigEntityResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function getPostDocument() {
+  protected function getPostDocument(): array {
     // @todo Update in https://www.drupal.org/node/2300677.
     return [];
   }
