@@ -16,7 +16,6 @@ use Drupal\Core\Url;
  * Functional class for the full integrated routing system.
  *
  * @group Routing
- * @group #slow
  */
 class RouterTest extends BrowserTestBase {
 
@@ -313,7 +312,7 @@ class RouterTest extends BrowserTestBase {
       \Drupal::service('router.route_provider')->getRouteByName('router_test.1');
       $this->fail('Route was delete on uninstall.');
     }
-    catch (RouteNotFoundException $e) {
+    catch (RouteNotFoundException) {
       // Expected exception; just continue testing.
     }
     // Install the module again.
