@@ -25,7 +25,6 @@ contains_element() {
   return 1
 }
 
-MEMORY_UNLIMITED=0
 CACHED=0
 DRUPALCI=0
 BRANCH=""
@@ -59,22 +58,12 @@ while test $# -gt 0; do
       DRUPALCI=1
       shift
       ;;
-    --memory-unlimited)
-      MEMORY_UNLIMITED=1
-      shift
-      ;;
     *)
       break
       ;;
   esac
 done
 
-memory_limit=""
-
-if [[ "$MEMORY_UNLIMITED" == "1" ]]; then
-  memory_limit="--memory-limit=-1"
-fi
-
 # Set up variables to make colored output simple. Color output is disabled on
 # DrupalCI because it is breaks reporting.
 # @todo https://www.drupal.org/project/drupalci_testbot/issues/3181869
@@ -216,25 +205,18 @@ fi
 cd "$TOP_LEVEL/core"
 
 # Ensure JavaScript development dependencies are installed.
-yarn check -s 2>/dev/null
-if [ "$?" -ne "0" ]; then
-  printf "Drupal's JavaScript development dependencies are not installed or cannot be resolved. Run 'yarn install' inside the core directory, or 'yarn check -s' to list other errors.\n"
-  DEPENDENCIES_NEED_INSTALLING=1;
-fi
-
-if [ $DEPENDENCIES_NEED_INSTALLING -ne 0 ]; then
-  exit 1;
-fi
+yarn --version
+yarn >/dev/null
 
 # Check all files for spelling in one go for better performance.
 if [[ $CSPELL_DICTIONARY_FILE_CHANGED == "1" ]] ; then
   printf "\nRunning spellcheck on *all* files.\n"
-  yarn run -s spellcheck:core --no-must-find-files --no-progress
+  yarn run spellcheck:core --no-must-find-files --no-progress
 else
   # Check all files for spelling in one go for better performance. We pipe the
   # list files in so we obey the globs set on the spellcheck:core command in
   # core/package.json.
-  echo "${ABS_FILES}" | tr ' ' '\n' | yarn run -s spellcheck:core --no-must-find-files --file-list stdin
+  echo "${ABS_FILES}" | tr ' ' '\n' | yarn run spellcheck:core --no-must-find-files --file-list stdin
 fi
 
 if [ "$?" -ne "0" ]; then
@@ -255,11 +237,11 @@ printf "\n"
 # APCu is disabled to ensure that the composer classmap is not corrupted.
 if [[ $PHPSTAN_DIST_FILE_CHANGED == "1" ]] || [[ "$DRUPALCI" == "1" ]]; then
   printf "\nRunning PHPStan on *all* files.\n"
-  php -d apc.enabled=0 -d apc.enable_cli=0 vendor/bin/phpstan analyze --no-progress --configuration="$TOP_LEVEL/core/phpstan.neon.dist" $memory_limit
+  php -d apc.enabled=0 -d apc.enable_cli=0 vendor/bin/phpstan analyze --no-progress --configuration="$TOP_LEVEL/core/phpstan.neon.dist"
 else
   # Only run PHPStan on changed files locally.
   printf "\nRunning PHPStan on changed files.\n"
-  php -d apc.enabled=0 -d apc.enable_cli=0 vendor/bin/phpstan analyze --no-progress --configuration="$TOP_LEVEL/core/phpstan-partial.neon" $ABS_FILES $memory_limit
+  php -d apc.enabled=0 -d apc.enable_cli=0 vendor/bin/phpstan analyze --no-progress --configuration="$TOP_LEVEL/core/phpstan-partial.neon" $ABS_FILES
 fi
 
 if [ "$?" -ne "0" ]; then
@@ -296,7 +278,7 @@ fi
 # When the eslint config has been changed, then eslint must check all files.
 if [[ $ESLINT_CONFIG_PASSING_FILE_CHANGED == "1" ]]; then
   cd "$TOP_LEVEL/core"
-  yarn run -s lint:core-js-passing "$TOP_LEVEL/core"
+  yarn run lint:core-js-passing "$TOP_LEVEL/core"
   CORRECTJS=$?
   if [ "$CORRECTJS" -ne "0" ]; then
     # If there are failures set the status to a number other than 0.
@@ -315,7 +297,7 @@ fi
 # When the stylelint config has been changed, then stylelint must check all files.
 if [[ $STYLELINT_CONFIG_FILE_CHANGED == "1" ]]; then
   cd "$TOP_LEVEL/core"
-  yarn run -s lint:css
+  yarn run lint:css
   if [ "$?" -ne "0" ]; then
     # If there are failures set the status to a number other than 0.
     FINAL_STATUS=1
@@ -336,7 +318,7 @@ fi
 # is in sync and conform to expectations.
 if [[ "$DRUPALCI" == "1" ]] && [[ $CKEDITOR5_PLUGINS_CHANGED == "1" ]]; then
   cd "$TOP_LEVEL/core"
-  yarn run -s check:ckeditor5
+  yarn run check:ckeditor5
   if [ "$?" -ne "0" ]; then
     # If there are failures set the status to a number other than 0.
     FINAL_STATUS=1
